#[repr(C, packed(1))]pub struct BaseboardInformationStruct {
pub hdr: Header,
pub manufacturer_str_idx: u8,
pub product_name_str_idx: u8,
pub version_str_idx: u8,
pub serial_number_str_idx: u8,
pub unsafe_asset_tag_str_idx: u8,
pub unsafe_feature_flags: u8,
pub unsafe_location_in_chassis_str_idx: u8,
pub unsafe_chassis_handle: U16,
pub unsafe_board_type: u8,
pub unsafe_contained_object_handles_count: u8,
}Expand description
SMBIOS Baseboard Information Struct.
Fields
hdr: Headermanufacturer_str_idx: u8product_name_str_idx: u8version_str_idx: u8serial_number_str_idx: u8unsafe_asset_tag_str_idx: u8unsafe_feature_flags: u8unsafe_location_in_chassis_str_idx: u8unsafe_chassis_handle: U16unsafe_board_type: u8unsafe_contained_object_handles_count: u8Implementations
Sourceimpl BaseboardInformationStruct
impl BaseboardInformationStruct
Sourcepub fn asset_tag_str_idx(&self) -> Option<u8>
pub fn asset_tag_str_idx(&self) -> Option<u8>
Returns the asset tag string index if present within the struct length.
Sourcepub fn feature_flags(&self) -> Option<u8>
pub fn feature_flags(&self) -> Option<u8>
Returns the feature flags if present within the struct length.
Sourcepub fn location_in_chassis_str_idx(&self) -> Option<u8>
pub fn location_in_chassis_str_idx(&self) -> Option<u8>
Returns the location in chassis string index if present within the struct length.
Sourcepub fn chassis_handle(&self) -> Option<u16>
pub fn chassis_handle(&self) -> Option<u16>
Returns the chassis handle if present within the struct length.
Sourcepub fn board_type(&self) -> Option<u8>
pub fn board_type(&self) -> Option<u8>
Returns the board type if present within the struct length.
Sourcepub fn contained_object_handles_count(&self) -> Option<u8>
pub fn contained_object_handles_count(&self) -> Option<u8>
Returns the contained object handles count if present within the struct length.
Sourcepub fn contained_object_handles<'a>(
&self,
raw_struct_bytes: &'a [u8],
) -> Option<&'a [U16]>
pub fn contained_object_handles<'a>( &self, raw_struct_bytes: &'a [u8], ) -> Option<&'a [U16]>
Returns the slice of contained object handles if present and valid within the struct length.
Sourcepub fn dump<W: Write>(&self, writer: &mut W, st: &StringTable<'_>) -> Result
pub fn dump<W: Write>(&self, writer: &mut W, st: &StringTable<'_>) -> Result
Formats a dump of the Baseboard Information Struct to the provided writer.