#[repr(C, packed(1))]pub struct EntryPoint2_1 {Show 14 fields
pub anchor_string: [u8; 4],
pub checksum: u8,
pub length: u8,
pub major_ver: u8,
pub minor_ver: u8,
pub max_struct_size: U16,
pub ep_rev: u8,
pub formatted_area: [u8; 5],
pub intermediate_anchor_string: [u8; 5],
pub intermediate_checksum: u8,
pub struct_table_length: U16,
pub struct_table_phys: U32,
pub struct_count: U16,
pub bcd_rev: u8,
}Expand description
System structure identifying where SMBIOS v2.1 structs are in memory.
Fields
anchor_string: [u8; 4]checksum: u8length: u8major_ver: u8minor_ver: u8max_struct_size: U16ep_rev: u8formatted_area: [u8; 5]intermediate_anchor_string: [u8; 5]intermediate_checksum: u8struct_table_length: U16struct_table_phys: U32struct_count: U16bcd_rev: u8Implementations
Sourceimpl EntryPoint2_1
impl EntryPoint2_1
Sourcepub fn is_valid(&self) -> bool
pub fn is_valid(&self) -> bool
Validates the entry point structure checksums and magic strings.
Sourcepub fn version(&self) -> SpecVersion
pub fn version(&self) -> SpecVersion
Returns the specification version supported by this entry point.